:hide-toc:

.. container:: noclass
   :name: forkongithub

   `Fork on GitHub <https://github.com/agile-geoscience/kosu>`_


kosu: Build and maintain courses
================================

    | ``kosu`` is a command-line utlity to help you build and maintain multi-day courses from content in Jupyter Notebooks.


Quick start
-----------

.. toctree::
    :caption: Quick start

Install ``kosu`` with pip:

.. code-block:: shell

    pip install kosu

``kosu`` is a command-line utility. To start a course or collection of courses, do this on the command line:

.. code-block:: shell

    mkdir mycourses
    cd mycourses
    kosu --init

This will create several directories and files in the directory mycourses.
You can run some of the other commands in this guide to see how they work.


User guide
----------

.. toctree::
    :maxdepth: 2
    :caption: User guide

    installation
    overview
    usage


Other resources
---------------

.. toctree::
    :maxdepth: 1
    :caption: Other resources

    development
    contributing
    authors
    license
    changelog


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. toctree::
    :caption: Project links
    :hidden:

    PyPI releases <https://pypi.org/project/kosu/>
    Code in GitHub <https://github.com/agile-geoscience/kosu>
    Issue tracker <https://github.com/agile-geoscience/kosu/issues>
    Community guidelines <https://code.agilescientific.com/community>
    Agile's software <https://code.agilescientific.com>
    Agile's website <https://www.agilescientific.com>
